@@ -270,6 +270,8 @@ class IO(object):
         data_in = EMPTY_BUFFER
         try:
             data_in = self._read_from_socket()
+            if len(data_in) == 0:
+                raise socket.error("connection closed by server")
         except socket.timeout:
             pass
         except compatibility.SSLWantReadError:
@@ -280,7 +282,10 @@ class IO(object):
             if why.args[0] not in (EWOULDBLOCK, EAGAIN):
                 self._exceptions.append(AMQPConnectionError(why))
                 if self._running.is_set():
-                    LOGGER.warning("Stopping inbound thread due to %s", why)
+                    LOGGER.warning(
+                        "Stopping inbound thread due to %s", why,
+                        exc_info=True
+                    )
                 self._running.clear()
         return data_in
 
