@@ -19,6 +19,8 @@ class Queue(ManagementHandler):
         :param str virtual_host: Virtual host name
 
         :raises ApiError: Raises if the remote server encountered an error.
+                          We also raise an exception if the queue cannot
+                          be found.
         :raises ApiConnectionError: Raises if there was a connectivity issue.
 
         :rtype: dict
@@ -31,11 +33,15 @@ class Queue(ManagementHandler):
             )
         )
 
-    def list(self, virtual_host='/', show_all=False):
+    def list(self, virtual_host='/', show_all=False,
+             name=None, page_size=100, use_regex=False):
         """List Queues.
 
         :param str virtual_host: Virtual host name
-        :param bool show_all: List all Queues
+        :param bool show_all: List Queues across all virtual hosts
+        :param name: Filter by name
+        :param use_regex: Enables regular expression for the param name
+        :param page_size: Number of elements per page
 
         :raises ApiError: Raises if the remote server encountered an error.
         :raises ApiConnectionError: Raises if there was a connectivity issue.
@@ -43,10 +49,14 @@ class Queue(ManagementHandler):
         :rtype: list
         """
         if show_all:
-            return self.http_client.get(API_QUEUES)
+            return self.http_client.list(
+                API_QUEUES,
+                name=name, use_regex=use_regex, page_size=page_size,
+            )
         virtual_host = quote(virtual_host, '')
-        return self.http_client.get(
-            API_QUEUES_VIRTUAL_HOST % virtual_host
+        return self.http_client.list(
+            API_QUEUES_VIRTUAL_HOST % virtual_host,
+            name=name, use_regex=use_regex, page_size=page_size,
         )
 
     def declare(self, queue='', virtual_host='/', passive=False, durable=False,
